=====================
Math notation example
=====================

When we describe the methods a repository implements, we frequently need to express some of the variables via inline mathematical notation (e.g. :math:`t` and :math:`\tau_i`) and some of their relations in displayed mathematical notation:

.. math:: t = \sum_{i=1}^n e^{\frac{1}{\tau_i}}

This page serves as an example of how such is done. 
